==> pdf-model-arlington-1.25.30-sources.jar: org/verapdf/model/alayer/ASignature.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface ASignature extends AObject {
	






	/**
	*/
	public Boolean getcontainsByteRange();

	/**
	*/
	public String getByteRangeType();

	/**
	*/
	public Boolean getByteRangeHasTypeArray();

	/**
	*/
	public Boolean getcontainsCert();

	/**
	*/
	public String getCertType();

	/**
	*/
	public Boolean getCertHasTypeArray();

	/**
	*/
	public Boolean getCertHasTypeStringByte();

	/**
	*/
	public Boolean getcontainsChanges();

	/**
	*/
	public String getChangesType();

	/**
	*/
	public Boolean getChangesHasTypeArray();

	/**
	*/
	public Boolean getcontainsContactInfo();

	/**
	*/
	public String getContactInfoType();

	/**
	*/
	public Boolean getContactInfoHasTypeStringText();

	/**
	*/
	public Boolean getcontainsContents();

	/**
	*/
	public String getContentsType();

	/**
	*/
	public Boolean getContentsHasTypeStringByte();

	/**
	*/
	public Boolean getisContentsHexString();

	/**
	*/
	public Boolean getcontainsFilter();

	/**
	*/
	public String getFilterType();

	/**
	*/
	public Boolean getFilterHasTypeName();

	/**
	*/
	public String getFilterNameValue();

	/**
	*/
	public Boolean getcontainsLocation();

	/**
	*/
	public String getLocationType();

	/**
	*/
	public Boolean getLocationHasTypeStringText();

	/**
	*/
	public Boolean getcontainsM();

	/**
	*/
	public String getMType();

	/**
	*/
	public Boolean getMHasTypeDate();

	/**
	*/
	public Boolean getcontainsName();

	/**
	*/
	public String getNameType();

	/**
	*/
	public Boolean getNameHasTypeStringText();

	/**
	*/
	public Boolean getcontainsProp_AuthTime();

	/**
	*/
	public String getProp_AuthTimeType();

	/**
	*/
	public Boolean getProp_AuthTimeHasTypeInteger();

	/**
	*/
	public Long getProp_AuthTimeIntegerValue();

	/**
	*/
	public Boolean getcontainsProp_AuthType();

	/**
	*/
	public String getProp_AuthTypeType();

	/**
	*/
	public Boolean getProp_AuthTypeHasTypeName();

	/**
	*/
	public Boolean getcontainsProp_Build();

	/**
	*/
	public String getProp_BuildType();

	/**
	*/
	public Boolean getProp_BuildHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsR();

	/**
	*/
	public String getRType();

	/**
	*/
	public Boolean getRHasTypeInteger();

	/**
	*/
	public Boolean getcontainsReason();

	/**
	*/
	public String getReasonType();

	/**
	*/
	public Boolean getReasonHasTypeStringText();

	/**
	*/
	public Boolean getcontainsReference();

	/**
	*/
	public String getReferenceType();

	/**
	*/
	public Boolean getReferenceHasTypeArray();

	/**
	*/
	public Boolean getcontainsSubFilter();

	/**
	*/
	public String getSubFilterType();

	/**
	*/
	public Boolean getSubFilterHasTypeName();

	/**
	*/
	public String getSubFilterNameValue();

	/**
	*/
	public Boolean getcontainsType();

	/**
	*/
	public String getTypeType();

	/**
	*/
	public Boolean getTypeHasTypeName();

	/**
	*/
	public String getTypeNameValue();

	/**
	*/
	public Boolean getcontainsV();

	/**
	*/
	public String getVType();

	/**
	*/
	public Boolean getVHasTypeInteger();
}

==> pdf-model-arlington-1.27.13-sources.jar: org/verapdf/model/alayer/ASignature.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface ASignature extends AObject {
	






	/**
	*/
	public Boolean getcontainsADBE_Build();

	/**
	*/
	public Boolean getisADBE_BuildIndirect();

	/**
	*/
	public String getADBE_BuildType();

	/**
	*/
	public Boolean getADBE_BuildHasTypeString();

	/**
	*/
	public Boolean getcontainsByteRange();

	/**
	*/
	public Boolean getisByteRangeIndirect();

	/**
	*/
	public String getByteRangeType();

	/**
	*/
	public Boolean getByteRangeHasTypeArray();

	/**
	*/
	public Long getByteRangeArraySize();

	/**
	*/
	public Boolean getcontainsCert();

	/**
	*/
	public Boolean getisCertIndirect();

	/**
	*/
	public String getCertType();

	/**
	*/
	public Boolean getCertHasTypeArray();

	/**
	*/
	public Boolean getCertHasTypeStringByte();

	/**
	*/
	public Boolean getcontainsChanges();

	/**
	*/
	public Boolean getisChangesIndirect();

	/**
	*/
	public String getChangesType();

	/**
	*/
	public Boolean getChangesHasTypeArray();

	/**
	*/
	public Boolean getcontainsContactInfo();

	/**
	*/
	public Boolean getisContactInfoIndirect();

	/**
	*/
	public String getContactInfoType();

	/**
	*/
	public Boolean getContactInfoHasTypeStringText();

	/**
	*/
	public Boolean getcontainsContents();

	/**
	*/
	public Boolean getisContentsIndirect();

	/**
	*/
	public String getContentsType();

	/**
	*/
	public Boolean getContentsHasTypeStringByte();

	/**
	*/
	public Boolean getisContentsHexString();

	/**
	*/
	public Boolean getcontainsFilter();

	/**
	*/
	public Boolean getisFilterIndirect();

	/**
	*/
	public String getFilterType();

	/**
	*/
	public Boolean getFilterHasTypeName();

	/**
	*/
	public String getFilterNameValue();

	/**
	*/
	public Boolean getcontainsLocation();

	/**
	*/
	public Boolean getisLocationIndirect();

	/**
	*/
	public String getLocationType();

	/**
	*/
	public Boolean getLocationHasTypeStringText();

	/**
	*/
	public Boolean getcontainsM();

	/**
	*/
	public Boolean getisMIndirect();

	/**
	*/
	public String getMType();

	/**
	*/
	public Boolean getMHasTypeDate();

	/**
	*/
	public Boolean getcontainsName();

	/**
	*/
	public Boolean getisNameIndirect();

	/**
	*/
	public String getNameType();

	/**
	*/
	public Boolean getNameHasTypeStringText();

	/**
	*/
	public Boolean getcontainsProp_AuthTime();

	/**
	*/
	public Boolean getisProp_AuthTimeIndirect();

	/**
	*/
	public String getProp_AuthTimeType();

	/**
	*/
	public Boolean getProp_AuthTimeHasTypeInteger();

	/**
	*/
	public Long getProp_AuthTimeIntegerValue();

	/**
	*/
	public Boolean getcontainsProp_AuthType();

	/**
	*/
	public Boolean getisProp_AuthTypeIndirect();

	/**
	*/
	public String getProp_AuthTypeType();

	/**
	*/
	public Boolean getProp_AuthTypeHasTypeName();

	/**
	*/
	public String getProp_AuthTypeNameValue();

	/**
	*/
	public Boolean getcontainsProp_Build();

	/**
	*/
	public Boolean getisProp_BuildIndirect();

	/**
	*/
	public String getProp_BuildType();

	/**
	*/
	public Boolean getProp_BuildHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsR();

	/**
	*/
	public Boolean getisRIndirect();

	/**
	*/
	public String getRType();

	/**
	*/
	public Boolean getRHasTypeInteger();

	/**
	*/
	public Boolean getcontainsReason();

	/**
	*/
	public Boolean getisReasonIndirect();

	/**
	*/
	public String getReasonType();

	/**
	*/
	public Boolean getReasonHasTypeStringText();

	/**
	*/
	public Boolean getcontainsReference();

	/**
	*/
	public Boolean getisReferenceIndirect();

	/**
	*/
	public String getReferenceType();

	/**
	*/
	public Boolean getReferenceHasTypeArray();

	/**
	*/
	public Boolean getcontainsSubFilter();

	/**
	*/
	public Boolean getisSubFilterIndirect();

	/**
	*/
	public String getSubFilterType();

	/**
	*/
	public Boolean getSubFilterHasTypeName();

	/**
	*/
	public String getSubFilterNameValue();

	/**
	*/
	public Boolean getcontainsType();

	/**
	*/
	public Boolean getisTypeIndirect();

	/**
	*/
	public String getTypeType();

	/**
	*/
	public Boolean getTypeHasTypeName();

	/**
	*/
	public String getTypeNameValue();

	/**
	*/
	public Boolean getcontainsV();

	/**
	*/
	public Boolean getisVIndirect();

	/**
	*/
	public String getVType();

	/**
	*/
	public Boolean getVHasTypeInteger();
}
